| cml | R Documentation |
Survival in a randomised trial comparing three treatments for Chronic Myelogeneous Leukemia (simulated data).
data("cml")
A data frame with 507 observations on the following 7 variables.
centera factor with 54 levels indicating the study center.
treatmenta factor with levels trt1, trt2, trt3 indicating the treatment group.
sexsex (0 = female, 1 = male)
ageage in years
riskgrouprisk group (0 = low, 1 = medium, 2 = high)
statuscensoring status (FALSE = censored, TRUE = dead)
timesurvival or censoring time in days.
The data are simulated according to structure of the data by the German CML Study Group used in \bibcitethehlmann1994.
*
if (require("coxme")) {
data("cml")
### one-sided simultaneous confidence intervals for many-to-one
### comparisons of treatment effects concerning time of survival
### modeled by a frailty Cox model with adjustment for further
### covariates and center-specific random effect.
cml_coxme <- coxme(Surv(time, status) ~ treatment + sex + age + riskgroup + (1|center),
data = cml)
glht_coxme <- glht(model = cml_coxme, linfct = mcp(treatment = "Dunnett"),
alternative = "greater")
ci_coxme <- confint(glht_coxme)
exp(ci_coxme$confint)[1:2,]
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.