Learn R Programming

multcomp (version 1.4-30)

cml: Chronic Myelogenous Leukemia survival data.

Description

Survival in a randomised trial comparing three treatments for Chronic Myelogeneous Leukemia (simulated data).

Usage

data("cml")

Arguments

Format

A data frame with 507 observations on the following 7 variables.

center

a factor with 54 levels indicating the study center.

treatment

a factor with levels trt1, trt2, trt3 indicating the treatment group.

sex

sex (0 = female, 1 = male)

age

age in years

riskgroup

risk group (0 = low, 1 = medium, 2 = high)

status

censoring status (FALSE = censored, TRUE = dead)

time

survival or censoring time in days.

Details

The data are simulated according to structure of the data by the German CML Study Group used in hehlmann1994.

References

*

Examples

Run this code

if (require("coxme")) {
    data("cml")
    ### one-sided simultaneous confidence intervals for many-to-one 
    ### comparisons of treatment effects concerning time of survival 
    ### modeled by a frailty Cox model with adjustment for further 
    ### covariates and center-specific random effect.
    cml_coxme <- coxme(Surv(time, status) ~ treatment + sex + age + riskgroup + (1|center), 
                       data = cml)
    glht_coxme <- glht(model = cml_coxme, linfct = mcp(treatment = "Dunnett"), 
                       alternative = "greater")
    ci_coxme <- confint(glht_coxme)
    exp(ci_coxme$confint)[1:2,]
}

Run the code above in your browser using DataLab