| contrMat | R Documentation |
Computes contrast matrices for several multiple comparison procedures.
contrMat(n, type = c("Dunnett", "Tukey", "Sequen", "AVE",
"Changepoint", "Williams", "Marcus",
"McDermott", "UmbrellaWilliams", "GrandMean"),
base = 1)
n |
a (possibly named) vector of sample sizes for each group. |
type |
type of contrast. |
base |
an integer specifying which group is considered the baseline group for Dunnett contrasts. |
Computes the requested matrix of contrasts for comparisons of mean levels. The general concept and specific choices are discussed by \bibcitethothorn2008b and \bibcitetBretz+Hothorn+Westfall_2010.
The matrix of contrasts with appropriate row names is returned.
*
n <- c(10,20,30,40)
names(n) <- paste("group", 1:4, sep="")
contrMat(n) # Dunnett is default
contrMat(n, base = 2) # use second level as baseline
contrMat(n, type = "Tukey")
contrMat(n, type = "Sequen")
contrMat(n, type = "AVE")
contrMat(n, type = "Changepoint")
contrMat(n, type = "Williams")
contrMat(n, type = "Marcus")
contrMat(n, type = "McDermott")
### Umbrella-protected Williams contrasts, i.e. a sequence of
### Williams-type contrasts with groups of higher order
### stepwise omitted
contrMat(n, type = "UmbrellaWilliams")
### comparison of each group with grand mean of all groups
contrMat(n, type = "GrandMean")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.