| detergent | R Documentation |
Detergent durability in an incomplete two-way design.
data("detergent")
This data frame contains the following variables
detergent, a factor at levels A, B,
C, D, and E.
block, a factor at levels B_1, ..., B_10.
response variable: number of plates washed before the foam disappears.
Plates were washed with five detergent varieties, in ten blocks. A complete design would have 50 combinations, here only three detergent varieties in each block were applied in a balanced incomplete block design. Note that there are six observations taken at each detergent level. The data were published by \bibcitetmultcomp::westfall1999.
*
### set up two-way ANOVA without interactions
amod <- aov(plates ~ block + detergent, data = detergent)
### set up all-pair comparisons
dht <- glht(amod, linfct = mcp(detergent = "Tukey"))
### see Westfall et al. (1999, p. 190)
confint(dht)
### see Westfall et al. (1999, p. 192)
summary(dht, test = univariate())
## Not run:
summary(dht, test = adjusted("Shaffer"))
summary(dht, test = adjusted("Westfall"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.