recovery: Recovery Time Data Set

recoveryR Documentation

Recovery Time Data Set

Description

Recovery time after surgery.

Usage

data("recovery")

Format

This data frame contains the following variables

blanket

blanket type, a factor at four levels: b0, b1, b2, and b3.

minutes

response variable: recovery time after a surgical procedure.

Details

A company developed specialized heating blankets designed to help the body heat following a surgical procedure. Four types of blankets were tried on surgical patients with the aim of comparing the recovery time of patients. One of the blanket was a standard blanket that had been in use already in various hospitals. Data were published by \bibcitetmultcomp::westfall1999, page 66.

References

\bibshow

*

Examples


  ### set up one-way ANOVA
  amod <- aov(minutes ~ blanket, data = recovery)

  ### set up multiple comparisons: one-sided Dunnett contrasts
  rht <- glht(amod, linfct = mcp(blanket = "Dunnett"), 
              alternative = "less")

  ### cf. Westfall et al. (1999, p. 80)
  confint(rht, level = 0.9)

  ### the same
  rht <- glht(amod, linfct = mcp(blanket = c("b1 - b0 >= 0", 
                                             "b2 - b0 >= 0", 
                                             "b3 - b0 >= 0")))
  confint(rht, level = 0.9)


multcomp documentation built on March 9, 2026, 5:08 p.m.