| recovery | R Documentation |
Recovery time after surgery.
data("recovery")
This data frame contains the following variables
blanket type, a factor at four levels: b0, b1,
b2, and b3.
response variable: recovery time after a surgical procedure.
A company developed specialized heating blankets designed to help the body heat following a surgical procedure. Four types of blankets were tried on surgical patients with the aim of comparing the recovery time of patients. One of the blanket was a standard blanket that had been in use already in various hospitals. Data were published by \bibcitetmultcomp::westfall1999, page 66.
*
### set up one-way ANOVA
amod <- aov(minutes ~ blanket, data = recovery)
### set up multiple comparisons: one-sided Dunnett contrasts
rht <- glht(amod, linfct = mcp(blanket = "Dunnett"),
alternative = "less")
### cf. Westfall et al. (1999, p. 80)
confint(rht, level = 0.9)
### the same
rht <- glht(amod, linfct = mcp(blanket = c("b1 - b0 >= 0",
"b2 - b0 >= 0",
"b3 - b0 >= 0")))
confint(rht, level = 0.9)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.